pub enum EquipmentSlotGroup {
Any,
MainHand,
OffHand,
Hand,
Feet,
Legs,
Chest,
Head,
Armor,
Body,
Saddle,
}Expand description
Equipment slot groups used by vanilla item attributes, loot, and enchantments.
Vanilla’s EquipmentSlotGroup is a predicate over concrete equipment slots:
Hand matches both hand slots, Armor matches humanoid and animal armor,
and Any matches every slot.
Variants
Implementations
Sourceimpl EquipmentSlotGroup
impl EquipmentSlotGroup
pub const fn id(self) -> i32
pub const fn by_id(id: i32) -> Self
pub const fn by_name(name: &str) -> Option<Self>
pub const fn name(self) -> &'static str
pub const fn as_str(self) -> &'static str
pub const fn by_slot(slot: EquipmentSlot) -> Self
pub const fn test(self, slot: EquipmentSlot) -> bool